==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/TransitionActionBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.TransitionActionBody;
import io.ciera.tool.sql.ooaofooa.body.TransitionActionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionSetImpl;

import java.util.Arrays;
import java.util.List;


public class TransitionActionBodySetImpl extends InstanceSet<TransitionActionBodySet,TransitionActionBody> implements TransitionActionBodySet {

    // attributes
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( TransitionActionBody transitionactionbody : this ) transitionactionbody.setAct_ID( ref_Act_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( TransitionActionBody transitionactionbody : this ) transitionactionbody.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( TransitionActionBody transitionactionbody : this ) transitionactionbody.setAction_ID( ref_Action_ID );
    }


    // selections
    @Override
    public ActionSet R688_specifies_processing_for_Action() throws XtumlException {
        ActionSet actionset = new ActionSetImpl();
        for ( TransitionActionBody transitionactionbody : this ) actionset.add( transitionactionbody.R688_specifies_processing_for_Action() );
        return actionset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( TransitionActionBody transitionactionbody : this ) bodyset.add( transitionactionbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public TransitionActionBody nullElement() {
        return TransitionActionBodyImpl.EMPTY_TRANSITIONACTIONBODY;
    }

    @Override
    public TransitionActionBodySet emptySet() {
      return new TransitionActionBodySetImpl();
    }

    @Override
    public TransitionActionBodySet value() {
        return this;
    }

    @Override
    public List<TransitionActionBody> elements() {
        return Arrays.asList(toArray(new TransitionActionBody[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/TransitionActionBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.TransitionActionBody;
import io.ciera.tool.sql.ooaofooa.body.TransitionActionBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class TransitionActionBodySetImpl extends InstanceSet<TransitionActionBodySet,TransitionActionBody> implements TransitionActionBodySet {

    public TransitionActionBodySetImpl() {
    }

    public TransitionActionBodySetImpl(Comparator<? super TransitionActionBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( TransitionActionBody transitionactionbody : this ) transitionactionbody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( TransitionActionBody transitionactionbody : this ) transitionactionbody.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( TransitionActionBody transitionactionbody : this ) transitionactionbody.setAct_ID( ref_Act_ID );
    }


    // selections
    @Override
    public ActionSet R688_specifies_processing_for_Action() throws XtumlException {
        ActionSet actionset = new ActionSetImpl();
        for ( TransitionActionBody transitionactionbody : this ) actionset.add( transitionactionbody.R688_specifies_processing_for_Action() );
        return actionset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( TransitionActionBody transitionactionbody : this ) bodyset.add( transitionactionbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public TransitionActionBody nullElement() {
        return TransitionActionBodyImpl.EMPTY_TRANSITIONACTIONBODY;
    }

    @Override
    public TransitionActionBodySet emptySet() {
      return new TransitionActionBodySetImpl();
    }

    @Override
    public TransitionActionBodySet emptySet(Comparator<? super TransitionActionBody> comp) {
      return new TransitionActionBodySetImpl(comp);
    }

    @Override
    public TransitionActionBodySet value() {
        return this;
    }

    @Override
    public List<TransitionActionBody> elements() {
        return Arrays.asList(toArray(new TransitionActionBody[0]));
    }

}
